@@ -1,7 +1,7 @@
 package Contenticious;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Contenticious::Content;
 use Carp;
@@ -54,7 +54,7 @@ sub startup {
         # found matching content node?
         my $content_node = $c->contenticious->find($path);
         unless (defined $content_node) {
-            $c->render_not_found;
+            $c->reply->not_found;
             return;
         }
 
